class PhotosController < ApplicationController

	before_filter :authenticate_user!, :except => [:show, :index]
	before_filter :redirect_if_not_admin, :except => [:show, :index]

  def index
		@selected_date = DateTime.now.beginning_of_day
    @date_countdown = @selected_date.beginning_of_year - 1.day
    @first_photo = FIRST_PHOTO
    page = params[:page]
    page = page.to_i - 1 unless page.nil?
    thumbnails_for = DateTime.parse(params[:thumbnails_for]) rescue nil
    sub_action = params[:sub_action] rescue 'default'

    respond_to do |format|
      format.html do

        case sub_action
        when 'infinitescroll'
          @photos = Photo.for_year @selected_date, (!current_user.nil? and current_user.is_admin?), page
          render :partial => 'big_photos_list', :locals => { :photos => @photos }
        when 'thumbnail'
            @photos = Photo.for_month thumbnails_for
            render :partial => 'photos_list', :locals => { :photos => @photos, :draw_header => false }
        else
          # for initial page load
          @photos = Photo.for_year @selected_date, (!current_user.nil? and current_user.is_admin?), page
        end

      	return
      end

      # for atom feed
      format.atom do
				@photos = Photo.get_last(30)
      	return
			end
    end
  end

  def show
  	begin
  		if params[:id].nil?
				@photo = Photo.get_last_published
			else
		 		@photo = Photo.find(params[:id])
		 	end

		 	if @photo.in_future? and (current_user.nil? or !current_user.is_admin?)
				redirect_to root_url
			else
				respond_to do |format|
				  format.html # show.html.erb
				  format.xml  { render :xml => @photo }
				end
			end
		rescue ActiveRecord::RecordNotFound => e
			logger.error "Exception in photos#show #{e}"
			render_404 e
		end
  end

  def new
    @photo = Photo.new
    @photo.date = Photo.get_next_date

    respond_to do |format|
      format.html # new.html.erb
      format.xml  { render :xml => @photo }
    end
  end

  def edit
    @photo = Photo.find(params[:id])
  end

  def create
    @photo = Photo.new(params[:photo])

    @photo.user = current_user

 		@photo.style.update_from_form params

    respond_to do |format|
      if @photo.save
        format.html { redirect_to photos_path, :notice => 'Photo was successfully updated.' }
        format.xml  { render :xml => @photo, :status => :created, :location => @photo }
      else
        format.html { render :action => "new" }
        format.xml  { render :xml => @photo.errors, :status => :unprocessable_entity }
      end
    end
  end

  def update
    @photo = Photo.find(params[:id])

		@photo.style.update_from_form params

    respond_to do |format|
      if @photo.update_attributes(params[:photo])
        format.html { redirect_to photo_path, :notice => 'Photo was successfully updated.' }
        format.xml  { head :ok }
      else
        format.html { render :action => "edit" }
        format.xml  { render :xml => @photo.errors, :status => :unprocessable_entity }
      end
    end
  end

  def destroy
    @photo = Photo.find(params[:id])
    @photo.destroy

    respond_to do |format|
      format.html { redirect_to(photos_url) }
      format.xml  { head :ok }
    end
  end

  private

  def redirect_if_not_admin
		redirect_to Photo.get_last_published unless current_user.is_admin?
  end

end
