class DateUniqueValidator < ActiveModel::Validator

	def validate(record)
		unless date_unique(record)
			record.errors[:base] << "You can only have one photo per date."
		end
	end
	
	private
	
	def date_unique(record)
	
		# testing here if unique, not if existent
		if record.date.nil?
			return true
		end
		
		# for new record numbersOfPhotos should be zero
		if record.new_record?
			numberOfPhotos = Photo.count(:conditions => ["date >= :date_start AND date <= :date_end", 
				{:date_start => record.date.to_date.beginning_of_day, 
					:date_end => record.date.to_date.end_of_day }])
		else # same for existing records, just need to exclude themselves from the check
			numberOfPhotos = Photo.count(:conditions => ["date >= :date_start AND date <= :date_end and id != :id", 
				{:date_start => record.date.to_date.beginning_of_day, 
					:date_end => record.date.to_date.end_of_day,
					:id => record.id }])
		end
		
		return numberOfPhotos == 0 ? true : false
	end
end
